mailr3400 - /1.3/relax_errors.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on November 04, 2007 - 13:42:
Author: bugman
Date: Sun Nov  4 13:42:08 2007
New Revision: 3400

URL: http://svn.gna.org/viewcvs/relax?rev=3400&view=rev
Log:
Replaced all mention of 'run' from the RelaxError system and replaced it with 
'pipe'.


Modified:
    1.3/relax_errors.py

Modified: 1.3/relax_errors.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/relax_errors.py?rev=3400&r1=3399&r2=3400&view=diff
==============================================================================
--- 1.3/relax_errors.py (original)
+++ 1.3/relax_errors.py Sun Nov  4 13:42:08 2007
@@ -128,17 +128,17 @@
 # PDB errors.
 #############
 
 # PDB data corresponding to the run already exists.
 class RelaxPdbError(BaseError):
-    def __init__(self, run):
-        self.text = "PDB data corresponding to the run " + `run` + " already 
exists."
+    def __init__(self, pipe):
+        self.text = "PDB data corresponding to the data pipe " + `pipe` + " 
already exists."
         if Debug:
             self.save_state()
 
 # No PDB loaded.
 class RelaxNoPdbError(BaseError):
-    def __init__(self, run):
-        self.text = "No PDB file has been loaded for the run " + `run` + "."
+    def __init__(self, pipe):
+        self.text = "No PDB file has been loaded for the data pipe " + 
`pipe` + "."
         if Debug:
             self.save_state()
 
@@ -151,8 +151,8 @@
 
 # No unit vectors.
 class RelaxNoVectorsError(BaseError):
-    def __init__(self, run):
-        self.text = "The unit XH bond vectors for the run " + `run` + " have 
not been calculated."
+    def __init__(self, pipe):
+        self.text = "The unit XH bond vectors for the data pipe " + `pipe` + 
" have not been calculated."
         if Debug:
             self.save_state()
 
@@ -389,22 +389,22 @@
 
 # No sequence loaded.
 class RelaxNoSequenceError(BaseError):
-    def __init__(self, run):
-        self.text = "The sequence data for the run " + `run` + " does not 
exist."
+    def __init__(self, pipe):
+        self.text = "The sequence data for the data pipe " + `pipe` + " does 
not exist."
         if Debug:
             self.save_state()
 
 # The sequence already exists.
 class RelaxSequenceError(BaseError):
-    def __init__(self, run):
-        self.text = "The sequence data for the run " + `run` + " already 
exists."
+    def __init__(self, pipe):
+        self.text = "The sequence data for the data pipe " + `pipe` + " 
already exists."
         if Debug:
             self.save_state()
 
 # The two sequences are different.
 class RelaxDiffSeqError(BaseError):
-    def __init__(self, run1, run2):
-        self.text = "The sequences for the runs " + `run1` + " and " + 
`run2` + " are not the same."
+    def __init__(self, pipe1, pipe2):
+        self.text = "The sequences for the data pipes " + `pipe1` + " and " 
+ `pipe2` + " are not the same."
         if Debug:
             self.save_state()
 
@@ -442,8 +442,8 @@
 
 # Model-free data already exists.
 class RelaxMfError(BaseError):
-    def __init__(self, run):
-        self.text = "Model-free data corresponding to the run " + `run` + " 
already exists."
+    def __init__(self, pipe):
+        self.text = "Model-free data corresponding to the data pipe " + 
`pipe` + " already exists."
         if Debug:
             self.save_state()
 
@@ -451,17 +451,17 @@
 # Tensor errors.
 ################
 
 # Diffusion tensor data corresponding to the run already exists.
 class RelaxTensorError(BaseError):
-    def __init__(self, run):
-        self.text = "Diffusion tensor data corresponding to the run " + 
`run` + " already exists."
+    def __init__(self, pipe):
+        self.text = "Diffusion tensor data corresponding to the data pipe " 
+ `pipe` + " already exists."
         if Debug:
             self.save_state()
 
 # No diffusion tensor data loaded.
 class RelaxNoTensorError(BaseError):
-    def __init__(self, run):
-        self.text = "No diffusion tensor data is loaded for the run " + 
`run` + "."
+    def __init__(self, pipe):
+        self.text = "No diffusion tensor data is loaded for the data pipe " 
+ `pipe` + "."
         if Debug:
             self.save_state()
 
@@ -569,8 +569,8 @@
 
 # The model has not been setup.
 class RelaxNoModelError(BaseError):
-    def __init__(self, run):
-        self.text = "The models corresponding to the run " + `run` + " have 
not been setup."
+    def __init__(self, pipe):
+        self.text = "The models corresponding to the data pipe " + `pipe` + 
" have not been setup."
         if Debug:
             self.save_state()
 
@@ -591,8 +591,8 @@
 
 # Value already exists.
 class RelaxValueError(BaseError):
-    def __init__(self, data_type, run):
-        self.text = "The data type " + `data_type` + " already exists for " 
+ `run` + "."
+    def __init__(self, data_type, pipe):
+        self.text = "The data type " + `data_type` + " already exists for 
the data pipe " + `pipe` + "."
         if Debug:
             self.save_state()
 
@@ -633,8 +633,8 @@
 
 # No simulations.
 class RelaxNoSimError(BaseError):
-    def __init__(self, run):
-        self.text = "Simulations for the run " + `run` + " have not been 
setup."
+    def __init__(self, pipe):
+        self.text = "Simulations for the data pipe " + `pipe` + " have not 
been setup."
         if Debug:
             self.save_state()
@@ -128,17 +128,17 @@
 #############
 
-# PDB data corresponding to the run already exists.
+# PDB data corresponding to the data pipe already exists.
 class RelaxPdbError(BaseError):
@@ -451,17 +451,17 @@
 ################
 
-# Diffusion tensor data corresponding to the run already exists.
+# Diffusion tensor data corresponding to the data pipe already exists.
 class RelaxTensorError(BaseError):
 




Related Messages


Powered by MHonArc, Updated Sun Nov 04 14:00:18 2007